@@ -250,6 +250,21 @@ def get_client_str(
     ``{username: "example", ip_address: "127.0.0.1", path_info: "/example/"}``
     """
 
+    if settings.AXES_CLIENT_STR_CALLABLE:
+        log.debug("Using settings.AXES_CLIENT_STR_CALLABLE to get client string.")
+
+        if callable(settings.AXES_CLIENT_STR_CALLABLE):
+            return settings.AXES_CLIENT_STR_CALLABLE(
+                username, ip_address, user_agent, path_info
+            )
+        if isinstance(settings.AXES_CLIENT_STR_CALLABLE, str):
+            return import_string(settings.AXES_CLIENT_STR_CALLABLE)(
+                username, ip_address, user_agent, path_info
+            )
+        raise TypeError(
+            "settings.AXES_CLIENT_STR_CALLABLE needs to be a string, callable or None."
+        )
+
     client_dict = dict()
 
     if settings.AXES_VERBOSE:
@@ -277,18 +292,42 @@ def get_client_str(
     return client_str
 
 
+def cleanse_parameters(params: dict) -> dict:
+    """
+    Replace sensitive parameter values in a parameter dict with
+    a safe placeholder value.
+
+    Parameters name ``'password'`` will always be cleansed.  Additionally,
+    parameters named in ``settings.AXES_SENSITIVE_PARAMETERS`` and
+    ``settings.AXES_PASSWORD_FORM_FIELD will be cleansed.
+
+    This is used to prevent passwords and similar values from
+    being logged in cleartext.
+    """
+    sensitive_parameters = ["password"] + settings.AXES_SENSITIVE_PARAMETERS
+    if settings.AXES_PASSWORD_FORM_FIELD:
+        sensitive_parameters.append(settings.AXES_PASSWORD_FORM_FIELD)
+
+    if sensitive_parameters:
+        cleansed = params.copy()
+        for param in sensitive_parameters:
+            if param in cleansed:
+                cleansed[param] = "********************"
+        return cleansed
+    return params
+
+
 def get_query_str(query: Type[QueryDict], max_length: int = 1024) -> str:
     """
     Turns a query dictionary into an easy-to-read list of key-value pairs.
 
-    If a field is called either ``'password'`` or ``settings.AXES_PASSWORD_FORM_FIELD`` it will be excluded.
+    If a field is called either ``'password'`` or ``settings.AXES_PASSWORD_FORM_FIELD`` or if the fieldname is included
+    in ``settings.AXES_SENSITIVE_PARAMETERS`` its value will be masked.
 
     The length of the output is limited to max_length to avoid a DoS attack via excessively large payloads.
     """
 
-    query_dict = query.copy()
-    query_dict.pop("password", None)
-    query_dict.pop(settings.AXES_PASSWORD_FORM_FIELD, None)
+    query_dict = cleanse_parameters(query.copy())
 
     template = Template("$key=$value")
     items = [{"key": k, "value": v} for k, v in query_dict.items()]
