@@ -23,6 +23,7 @@ from axes.helpers import (
     is_ip_address_in_whitelist,
     is_user_attempt_whitelisted,
     toggleable,
+    cleanse_parameters,
 )
 from axes.models import AccessAttempt
 from tests.base import AxesTestCase
@@ -224,6 +225,16 @@ class ClientStringTestCase(AxesTestCase):
 
         self.assertEqual(expected, actual)
 
+    @override_settings(AXES_CLIENT_STR_CALLABLE="tests.test_helpers.get_dummy_client_str")
+    def test_get_client_str_callable(self):
+        self.assertEqual(
+            get_client_str("username", "ip_address", "user_agent", "path_info"),
+            "client string"
+        )
+
+def get_dummy_client_str(username, ip_address, user_agent, path_info):
+    return "client string"
+
 
 class ClientParametersTestCase(AxesTestCase):
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -602,6 +613,7 @@ class LockoutResponseTestCase(AxesTestCase):
         response = get_lockout_response(request=self.request)
         self.assertEqual(type(response), HttpResponse)
 
+
 def mock_get_cool_off_str():
     return timedelta(seconds=30)
 
@@ -681,3 +693,40 @@ class AxesLockoutTestCase(AxesTestCase):
     def test_get_lockout_response_override_invalid(self):
         with self.assertRaises(TypeError):
             get_lockout_response(self.request, self.credentials)
+
+
+class AxesCleanseParamsTestCase(AxesTestCase):
+    def setUp(self):
+        self.parameters = {
+            "username": "test_user",
+            "password": "test_password",
+            "other_sensitive_data": "sensitive",
+        }
+
+    def test_cleanse_parameters(self):
+        cleansed = cleanse_parameters(self.parameters)
+        self.assertEqual("test_user", cleansed["username"])
+        self.assertEqual("********************", cleansed["password"])
+        self.assertEqual("sensitive", cleansed["other_sensitive_data"])
+
+    @override_settings(AXES_SENSITIVE_PARAMETERS=["other_sensitive_data"])
+    def test_cleanse_parameters_override_sensitive(self):
+        cleansed = cleanse_parameters(self.parameters)
+        self.assertEqual("test_user", cleansed["username"])
+        self.assertEqual("********************", cleansed["password"])
+        self.assertEqual("********************", cleansed["other_sensitive_data"])
+
+    @override_settings(AXES_SENSITIVE_PARAMETERS=["other_sensitive_data"])
+    @override_settings(AXES_PASSWORD_FORM_FIELD="username")
+    def test_cleanse_parameters_override_both(self):
+        cleansed = cleanse_parameters(self.parameters)
+        self.assertEqual("********************", cleansed["username"])
+        self.assertEqual("********************", cleansed["password"])
+        self.assertEqual("********************", cleansed["other_sensitive_data"])
+
+    @override_settings(AXES_PASSWORD_FORM_FIELD=None)
+    def test_cleanse_parameters_override_empty(self):
+        cleansed = cleanse_parameters(self.parameters)
+        self.assertEqual("test_user", cleansed["username"])
+        self.assertEqual("********************", cleansed["password"])
+        self.assertEqual("sensitive", cleansed["other_sensitive_data"])
